require 'pr-daikou/version'
require 'pr-daikou/cli'

require 'pr-daikou/host/github'

# Create pull request of CI Service
module PRDaikou
  module_function

  def exec(options, _args, current_time = Time.now)
    if ENV['GITHUB_ACCESS_TOKEN'].nil?
      raise 'Please input ENV of GITHUB_ACCESS_TOKEN'
    end

    unless options[:only_pullrequest]
      return unless code_changed?

      PRDaikou::Host::Github.create_branch(
        options[:email],
        options[:name],
        topic_branch(options[:topic], current_time),
        options[:commit]
      )
    end

    pullrequest_number =
      PRDaikou::Host::Github.create_pullrequest(
        pullrequest_title(options[:title]),
        pullrequest_description(options[:description]),
        options[:base],
        topic_branch(options[:topic], current_time)
      )
    unless options[:labels].empty?
      PRDaikou::Host::Github.add_labels_to_pullrequest(
        pullrequest_number,
        options[:labels].split(',').map(&:strip)
      )
    end

    true
  end

  def code_changed?
    `git diff --numstat` != ''
  end

  def topic_branch(topic_name, current_time)
    if topic_name == 'ci/pr-daikou'
      "#{topic_name}_#{current_time.strftime('%Y%m%d%H%M%S.%L')}"
    else
      topic_name
    end
  end

  def pullrequest_title(title)
    "#{title} at #{`echo -n $(date)`}"
  end

  def pullrequest_description(description)
    if description == ''
      'Auto generated by [PR daikou](https://rubygems.org/gems/pr-daikou)'
    else
      <<~DESCRIPTION
        #{description}
        Auto generated by [PR daikou](https://rubygems.org/gems/pr-daikou)
      DESCRIPTION
    end
  end
end
